==> vertx-rx-java-gen-3.9.2.redhat-00001-test-sources.jar: io/vertx/rxjava/codegen/testmodel/AnyJavaTypeTCK.java <==
/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.vertx.rxjava.codegen.testmodel;

import rx.Observable;
import rx.Single;
import io.vertx.rx.java.RxHelper;
import io.vertx.rx.java.WriteStreamSubscriber;
import io.vertx.rx.java.SingleOnSubscribeAdapter;
import java.util.Map;
import java.util.Set;
import java.util.List;
import java.util.Iterator;
import java.util.function.Function;
import java.util.stream.Collectors;
import io.vertx.core.Handler;
import io.vertx.core.AsyncResult;
import io.vertx.core.json.JsonObject;
import io.vertx.core.json.JsonArray;
import io.vertx.lang.rx.RxGen;
import io.vertx.lang.rx.TypeArg;
import io.vertx.lang.rx.MappingIterator;


@RxGen(io.vertx.codegen.testmodel.AnyJavaTypeTCK.class)
public class AnyJavaTypeTCK {

  @Override
  public String toString() {
    return delegate.toString();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AnyJavaTypeTCK that = (AnyJavaTypeTCK) o;
    return delegate.equals(that.delegate);
  }
  
  @Override
  public int hashCode() {
    return delegate.hashCode();
  }

  public static final TypeArg<AnyJavaTypeTCK> __TYPE_ARG = new TypeArg<>(    obj -> new AnyJavaTypeTCK((io.vertx.codegen.testmodel.AnyJavaTypeTCK) obj),
    AnyJavaTypeTCK::getDelegate
  );

  private final io.vertx.codegen.testmodel.AnyJavaTypeTCK delegate;
  
  public AnyJavaTypeTCK(io.vertx.codegen.testmodel.AnyJavaTypeTCK delegate) {
    this.delegate = delegate;
  }

  public AnyJavaTypeTCK(Object delegate) {
    this.delegate = (io.vertx.codegen.testmodel.AnyJavaTypeTCK)delegate;
  }

  public io.vertx.codegen.testmodel.AnyJavaTypeTCK getDelegate() {
    return delegate;
  }


  public void methodWithJavaTypeParam(java.net.Socket socket) { 
    delegate.methodWithJavaTypeParam(socket);
  }

  public void methodWithListOfJavaTypeParam(List<java.net.Socket> socketList) { 
    delegate.methodWithListOfJavaTypeParam(socketList);
  }

  public void methodWithSetOfJavaTypeParam(Set<java.net.Socket> socketSet) { 
    delegate.methodWithSetOfJavaTypeParam(socketSet);
  }

  public void methodWithMapOfJavaTypeParam(java.util.Map<String, java.net.Socket> socketMap) { 
    delegate.methodWithMapOfJavaTypeParam(socketMap);
  }

  public java.net.Socket methodWithJavaTypeReturn() { 
    java.net.Socket ret = delegate.methodWithJavaTypeReturn();
    return ret;
  }

  public List<java.net.Socket> methodWithListOfJavaTypeReturn() { 
    List<java.net.Socket> ret = delegate.methodWithListOfJavaTypeReturn();
    return ret;
  }

  public Set<java.net.Socket> methodWithSetOfJavaTypeReturn() { 
    Set<java.net.Socket> ret = delegate.methodWithSetOfJavaTypeReturn();
    return ret;
  }

  public java.util.Map<String, java.net.Socket> methodWithMapOfJavaTypeReturn() { 
    java.util.Map<String, java.net.Socket> ret = delegate.methodWithMapOfJavaTypeReturn();
    return ret;
  }

  public void methodWithHandlerJavaTypeParam(Handler<java.net.Socket> socketHandler) { 
    delegate.methodWithHandlerJavaTypeParam(socketHandler);
  }

  public void methodWithHandlerListOfJavaTypeParam(Handler<List<java.net.Socket>> socketListHandler) { 
    delegate.methodWithHandlerListOfJavaTypeParam(socketListHandler);
  }

  public void methodWithHandlerSetOfJavaTypeParam(Handler<Set<java.net.Socket>> socketSetHandler) { 
    delegate.methodWithHandlerSetOfJavaTypeParam(socketSetHandler);
  }

  public void methodWithHandlerMapOfJavaTypeParam(Handler<java.util.Map<String, java.net.Socket>> socketMapHandler) { 
    delegate.methodWithHandlerMapOfJavaTypeParam(socketMapHandler);
  }

  public void methodWithHandlerAsyncResultJavaTypeParam(Handler<AsyncResult<java.net.Socket>> socketHandler) { 
    delegate.methodWithHandlerAsyncResultJavaTypeParam(socketHandler);
  }

    @Deprecated()
  public Observable<java.net.Socket> methodWithHandlerAsyncResultJavaTypeParamObservable() { 
    io.vertx.rx.java.ObservableFuture<java.net.Socket> socketHandler = io.vertx.rx.java.RxHelper.observableFuture();
    methodWithHandlerAsyncResultJavaTypeParam(socketHandler.toHandler());
    return socketHandler;
  }

  public Single<java.net.Socket> rxMethodWithHandlerAsyncResultJavaTypeParam() { 
    return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
      methodWithHandlerAsyncResultJavaTypeParam(fut);
    }));
  }

  public void methodWithHandlerAsyncResultListOfJavaTypeParam(Handler<AsyncResult<List<java.net.Socket>>> socketListHandler) { 
    delegate.methodWithHandlerAsyncResultListOfJavaTypeParam(socketListHandler);
  }

    @Deprecated()
  public Observable<List<java.net.Socket>> methodWithHandlerAsyncResultListOfJavaTypeParamObservable() { 
    io.vertx.rx.java.ObservableFuture<List<java.net.Socket>> socketListHandler = io.vertx.rx.java.RxHelper.observableFuture();
    methodWithHandlerAsyncResultListOfJavaTypeParam(socketListHandler.toHandler());
    return socketListHandler;
  }

  public Single<List<java.net.Socket>> rxMethodWithHandlerAsyncResultListOfJavaTypeParam() { 
    return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
      methodWithHandlerAsyncResultListOfJavaTypeParam(fut);
    }));
  }

  public void methodWithHandlerAsyncResultSetOfJavaTypeParam(Handler<AsyncResult<Set<java.net.Socket>>> socketSetHandler) { 
    delegate.methodWithHandlerAsyncResultSetOfJavaTypeParam(socketSetHandler);
  }

    @Deprecated()
  public Observable<Set<java.net.Socket>> methodWithHandlerAsyncResultSetOfJavaTypeParamObservable() { 
    io.vertx.rx.java.ObservableFuture<Set<java.net.Socket>> socketSetHandler = io.vertx.rx.java.RxHelper.observableFuture();
    methodWithHandlerAsyncResultSetOfJavaTypeParam(socketSetHandler.toHandler());
    return socketSetHandler;
  }

  public Single<Set<java.net.Socket>> rxMethodWithHandlerAsyncResultSetOfJavaTypeParam() { 
    return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
      methodWithHandlerAsyncResultSetOfJavaTypeParam(fut);
    }));
  }

  public void methodWithHandlerAsyncResultMapOfJavaTypeParam(Handler<AsyncResult<java.util.Map<String, java.net.Socket>>> socketMapHandler) { 
    delegate.methodWithHandlerAsyncResultMapOfJavaTypeParam(socketMapHandler);
  }

    @Deprecated()
  public Observable<java.util.Map<String, java.net.Socket>> methodWithHandlerAsyncResultMapOfJavaTypeParamObservable() { 
    io.vertx.rx.java.ObservableFuture<java.util.Map<String, java.net.Socket>> socketMapHandler = io.vertx.rx.java.RxHelper.observableFuture();
    methodWithHandlerAsyncResultMapOfJavaTypeParam(socketMapHandler.toHandler());
    return socketMapHandler;
  }

  public Single<java.util.Map<String, java.net.Socket>> rxMethodWithHandlerAsyncResultMapOfJavaTypeParam() { 
    return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
      methodWithHandlerAsyncResultMapOfJavaTypeParam(fut);
    }));
  }

  public static AnyJavaTypeTCK newInstance(io.vertx.codegen.testmodel.AnyJavaTypeTCK arg) {
    return arg != null ? new AnyJavaTypeTCK(arg) : null;
  }

}

==> vertx-rx-java-gen-4.0.0.redhat-00001-test-sources.jar: io/vertx/rxjava/codegen/testmodel/AnyJavaTypeTCK.java <==
/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.vertx.rxjava.codegen.testmodel;

import rx.Observable;
import rx.Single;
import io.vertx.rx.java.RxHelper;
import io.vertx.rx.java.WriteStreamSubscriber;
import io.vertx.rx.java.SingleOnSubscribeAdapter;
import java.util.Map;
import java.util.Set;
import java.util.List;
import java.util.Iterator;
import java.util.function.Function;
import java.util.stream.Collectors;
import io.vertx.core.Handler;
import io.vertx.core.AsyncResult;
import io.vertx.core.json.JsonObject;
import io.vertx.core.json.JsonArray;
import io.vertx.lang.rx.RxGen;
import io.vertx.lang.rx.TypeArg;
import io.vertx.lang.rx.MappingIterator;


@RxGen(io.vertx.codegen.testmodel.AnyJavaTypeTCK.class)
public class AnyJavaTypeTCK {

  @Override
  public String toString() {
    return delegate.toString();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AnyJavaTypeTCK that = (AnyJavaTypeTCK) o;
    return delegate.equals(that.delegate);
  }
  
  @Override
  public int hashCode() {
    return delegate.hashCode();
  }

  public static final TypeArg<AnyJavaTypeTCK> __TYPE_ARG = new TypeArg<>(    obj -> new AnyJavaTypeTCK((io.vertx.codegen.testmodel.AnyJavaTypeTCK) obj),
    AnyJavaTypeTCK::getDelegate
  );

  private final io.vertx.codegen.testmodel.AnyJavaTypeTCK delegate;
  
  public AnyJavaTypeTCK(io.vertx.codegen.testmodel.AnyJavaTypeTCK delegate) {
    this.delegate = delegate;
  }

  public AnyJavaTypeTCK(Object delegate) {
    this.delegate = (io.vertx.codegen.testmodel.AnyJavaTypeTCK)delegate;
  }

  public io.vertx.codegen.testmodel.AnyJavaTypeTCK getDelegate() {
    return delegate;
  }


  public void methodWithJavaTypeParam(java.net.Socket socket) { 
    delegate.methodWithJavaTypeParam(socket);
  }

  public void methodWithListOfJavaTypeParam(List<java.net.Socket> socketList) { 
    delegate.methodWithListOfJavaTypeParam(socketList);
  }

  public void methodWithSetOfJavaTypeParam(Set<java.net.Socket> socketSet) { 
    delegate.methodWithSetOfJavaTypeParam(socketSet);
  }

  public void methodWithMapOfJavaTypeParam(java.util.Map<String, java.net.Socket> socketMap) { 
    delegate.methodWithMapOfJavaTypeParam(socketMap);
  }

  public java.net.Socket methodWithJavaTypeReturn() { 
    java.net.Socket ret = delegate.methodWithJavaTypeReturn();
    return ret;
  }

  public List<java.net.Socket> methodWithListOfJavaTypeReturn() { 
    List<java.net.Socket> ret = delegate.methodWithListOfJavaTypeReturn();
    return ret;
  }

  public Set<java.net.Socket> methodWithSetOfJavaTypeReturn() { 
    Set<java.net.Socket> ret = delegate.methodWithSetOfJavaTypeReturn();
    return ret;
  }

  public java.util.Map<String, java.net.Socket> methodWithMapOfJavaTypeReturn() { 
    java.util.Map<String, java.net.Socket> ret = delegate.methodWithMapOfJavaTypeReturn();
    return ret;
  }

  public void methodWithHandlerJavaTypeParam(Handler<java.net.Socket> socketHandler) { 
    delegate.methodWithHandlerJavaTypeParam(socketHandler);
  }

  public void methodWithHandlerListOfJavaTypeParam(Handler<List<java.net.Socket>> socketListHandler) { 
    delegate.methodWithHandlerListOfJavaTypeParam(socketListHandler);
  }

  public void methodWithHandlerSetOfJavaTypeParam(Handler<Set<java.net.Socket>> socketSetHandler) { 
    delegate.methodWithHandlerSetOfJavaTypeParam(socketSetHandler);
  }

  public void methodWithHandlerMapOfJavaTypeParam(Handler<java.util.Map<String, java.net.Socket>> socketMapHandler) { 
    delegate.methodWithHandlerMapOfJavaTypeParam(socketMapHandler);
  }

  public void methodWithHandlerAsyncResultJavaTypeParam(Handler<AsyncResult<java.net.Socket>> socketHandler) { 
    delegate.methodWithHandlerAsyncResultJavaTypeParam(socketHandler);
  }

  public void methodWithHandlerAsyncResultJavaTypeParam() {
    methodWithHandlerAsyncResultJavaTypeParam(ar -> { });
  }

    public Single<java.net.Socket> rxMethodWithHandlerAsyncResultJavaTypeParam() { 
    return Single.create(new SingleOnSubscribeAdapter<>(fut -> {
      methodWithHandlerAsyncResultJavaTypeParam(fut);
    }));
  }

  public void methodWithHandlerAsyncResultListOfJavaTypeParam(Handler<AsyncResult<List<java.net.Socket>>> socketListHandler) { 
    delegate.methodWithHandlerAsyncResultListOfJavaTypeParam(socketListHandler);
  }

  public void methodWithHandlerAsyncResultListOfJavaTypeParam() {
    methodWithHandlerAsyncResultListOfJavaTypeParam(ar -> { });
  }

    public Single<List<java.net.Socket>> rxMethodWithHandlerAsyncResultListOfJavaTypeParam() { 
    return Single.create(new SingleOnSubscribeAdapter<>(fut -> {
      methodWithHandlerAsyncResultListOfJavaTypeParam(fut);
    }));
  }

  public void methodWithHandlerAsyncResultSetOfJavaTypeParam(Handler<AsyncResult<Set<java.net.Socket>>> socketSetHandler) { 
    delegate.methodWithHandlerAsyncResultSetOfJavaTypeParam(socketSetHandler);
  }

  public void methodWithHandlerAsyncResultSetOfJavaTypeParam() {
    methodWithHandlerAsyncResultSetOfJavaTypeParam(ar -> { });
  }

    public Single<Set<java.net.Socket>> rxMethodWithHandlerAsyncResultSetOfJavaTypeParam() { 
    return Single.create(new SingleOnSubscribeAdapter<>(fut -> {
      methodWithHandlerAsyncResultSetOfJavaTypeParam(fut);
    }));
  }

  public void methodWithHandlerAsyncResultMapOfJavaTypeParam(Handler<AsyncResult<java.util.Map<String, java.net.Socket>>> socketMapHandler) { 
    delegate.methodWithHandlerAsyncResultMapOfJavaTypeParam(socketMapHandler);
  }

  public void methodWithHandlerAsyncResultMapOfJavaTypeParam() {
    methodWithHandlerAsyncResultMapOfJavaTypeParam(ar -> { });
  }

    public Single<java.util.Map<String, java.net.Socket>> rxMethodWithHandlerAsyncResultMapOfJavaTypeParam() { 
    return Single.create(new SingleOnSubscribeAdapter<>(fut -> {
      methodWithHandlerAsyncResultMapOfJavaTypeParam(fut);
    }));
  }

  public static AnyJavaTypeTCK newInstance(io.vertx.codegen.testmodel.AnyJavaTypeTCK arg) {
    return arg != null ? new AnyJavaTypeTCK(arg) : null;
  }

}
